# topsis_rupanshi_102017010
topsis_rupanshi_102017010 is a Python Package implementing [Topsis](https://en.wikipedia.org/wiki/TOPSIS) method used for multi-criteria decision analysis.
Topsis stands for 'Technique for Order of Preference by Similarity to Ideal Solution'.

## Installation
Install the Package using the command - 
```s
$ pip install topsis_rupanshi_102017010
```

## License

MIT

**Free Software, Hell Yeah!**